#########################################################################################
#                                                                                       #
#                Replicability and generalizability of PTSD networks:                   #
#                a cross-cultural multisite study of PTSD symptoms in                   #
#                         four samples of trauma patients                               #
#                                                                                       #
#                   Fried et al. 2018, Clinical Psychological Science                   #
#                                                                                       #
#---------------------------------------------------------------------------------------#
#                                                                                       #
#                   URL & DOI: https://doi.org/10.1177/2167702617745092                 #
#              Preprint and Supplementary materials at: https://osf.io/2t7qp/           #
#                                                                                       #
#########################################################################################



# ---------- Table of Contents ----------------------------------------------------------
# ---------- 1. Load Libraries ----------------------------------------------------------
# ---------- 2. Load & manipulate data --------------------------------------------------
# ---------- 3. Descriptives ------------------------------------------------------------
# ---------- 4. Estimate networks individually ------------------------------------------
# ---------- 5. Stability and accuracy for individually estimated networks --------------
# ---------- 6. Joint network estimation ------------------------------------------------
# ---------- 7. Centrality for 4 jointly estimated networks -----------------------------
# ---------- 8. Network comparison tests for 4 jointly estimated networks ---------------
# ---------- 9. Pool data into one full network -----------------------------------------
# ---------- 10. Compare to McNally et al. 2015 -----------------------------------------
# ---------- 11. How to reproduce network analysis without data -------------------------


# ---------------------------------------------------------------------------------------
# ---------- 1. Load libraries ----------------------------------------------------------
# ---------------------------------------------------------------------------------------

library("qgraph")
library("dplyr")
# devtools::install_github("GiulioCostantini/EstimateGroupNetwork")
library("EstimateGroupNetwork")
library("bootnet")
library("mgm")
library("haven")
library("reshape2")
library("readr")
# devtools::install_github("cvborkulo/NetworkComparisonTest")
library("NetworkComparisonTest")
library("BayesFactor")
library("psych")
library("lavaan")


# ---------------------------------------------------------------------------------------
# ---------- 2. Load & manipulate data --------------------------------------------------
# ---------------------------------------------------------------------------------------

### Load files
load(file="names.RData")

### Load data
data1 <- read_sav("data1.sav") 
data2 <- read_sav("data2.sav")
data3 <- read_delim("data3.csv", ";", escape_double = FALSE, trim_ws = TRUE)
data4.1 <- read_csv("data4.1.csv")
data4.2 <- read_csv("data4.2.csv")
data4 <- rbind(data4.1, data4.2)                   # merge data
data4[, 1:16] <- sapply(data4[, 1:16], as.numeric) # repair data
data4[, 1:16] <- sapply(data4[, 1:16], trunc)      # repair data

# re-order columns to fit DSM-IV
data1 <- data1[,c(1,3,2,16,15,11,12,13,4,5,14,8,10,7,9,6)]
data2 <- data2[,c(1,3,2,16,15,11,12,13,4,5,14,8,10,7,9,6)]
data3 <- data3[,c(1,3,2,16,15,11,12,13,4,5,14,8,10,7,9,6)]
data4 <- data4[,c(1,3,2,16,15,11,12,13,4,5,14,8,10,7,9,6)]

colnames(data1) <- colnames(data2) <- colnames(data3) <- colnames(data4) <- c(1:16)  

names <- c("Intrusions", "Nightmares", "Flashbacks", "Physio-/psychological reactivity", "Avoidance of thoughts", "Avoidance of situations", 
           "Amnesia", "Disinterest in activities", "Feeling detached", "Emotional numbing", "Forshortened future", 
           "Sleep problems", "Irritability", "Concentration problems", "Hypervigilance", "Startle response")

shortnames <- c("1-Intr","2-Nightm","3-Flash","4-React","5-AvThought","6-AvSit","7-Amnes","8-Disint","9-Detach","10-EmoNumb","11-ShortFut","12-Sleep","13-Irrit","14-Conc","15-Hyperv","16-Startl")

# define DSM-IV symptom groups
# gr <- list(c(1:4), c(5:11), c(12:16))
          
### Save output
# save(names, shortnames, file="names.RData")


# ---------------------------------------------------------------------------------------
# ---------- 3. Descriptives ------------------------------------------------------------
# ---------------------------------------------------------------------------------------

### Load files
load(file="Means_SDs.RData")

### Missing data
data1 <- apply(data1, 2, function(x) {x[x == -999] <- NA; x}) 
data2 <- apply(data2, 2, function(x) {x[x == -999] <- NA; x})
data3 <- apply(data3, 2, function(x) {x[x == -999] <- NA; x})
data4 <- apply(data4, 2, function(x) {x[x == 999] <- NA; x})
data4 <- apply(data4, 2, function(x) {x[x == 777] <- NA; x})

data1 <- as.data.frame(data1)  
data2 <- as.data.frame(data2)  
data3 <- as.data.frame(data3)  
data4 <- as.data.frame(data4)  

nrow(data1)          # 526 
nrow(na.omit(data1)) # 517
nrow(data2)          # 365
nrow(na.omit(data2)) # 363
nrow(data3)          # 926
nrow(na.omit(data3)) # 923
nrow(data4)          # 965
nrow(na.omit(data4)) # 928

data1miss<-na.omit(data1) 
data2miss<-na.omit(data2)
data3miss<-na.omit(data3)
data4miss<-na.omit(data4)

### Means and standard deviations
means1 <- colMeans(data1, na.rm=T)
sds1 <- as.vector(sapply(data1, sd, na.rm=T))

means2 <- colMeans(data2, na.rm=T)
sds2 <- as.vector(sapply(data2, sd, na.rm=T))

means3 <- colMeans(data3, na.rm=T)
means3 <- means3 * 4/5 # this dataset has a range 1-5, the others 1-4; for descriptives we want the same range
sds3 <- as.vector(sapply(data3, sd, na.rm=T)) # standard deviations, but bigger because the range is wider; so below we adjust that
data3x <- as.vector(data3)* 4/5
mmm <- matrix(NA, 926,16)
mmm <- data3x
sds3 <- as.vector(sapply(mmm, sd, na.rm=T)) # this is adjusted by 4/5 now; we overwrite sds3 here.

means4 <- colMeans(data4, na.rm=T); 
sds4 <- as.vector(sapply(data4, sd, na.rm=T))

# Plot means and standard deviations
means <- as.data.frame(cbind(means1,means2, means3, means4))
#means$bla <- rowMeans(means)

means <- mutate(means, id = rownames(means))
colnames(means)<-c("1", "2", "3", "4", "Symptoms")
means_long <- melt(means, id="Symptoms")
means_long$Symptoms <- as.numeric(means_long$Symptoms)
names(means_long)[2] <- "Datasets"
type <- c("Mean")
means_long <- cbind(means_long, type)

sds <- as.data.frame(cbind(sds1,sds2, sds3, sds4))
sds <- mutate(sds, id = rownames(sds))
colnames(sds)<-c("1", "2", "3", "4", "Symptoms")
sds_long <- melt(sds, id="Symptoms")
sds_long$Symptoms <- as.numeric(sds_long$Symptoms)
names(sds_long)[2] <- "Datasets"
type <- c("SD")
sds_long <- cbind(sds_long, type)

merged <- rbind(means_long, sds_long)
colnames(merged)[4] <- "Type"

pdf("Fig9s.pdf", width=6, height=4.5,useDingbats=FALSE)  # Did not end up in paper, see supplementary materials
p1 <- ggplot(data=merged, aes(x=Symptoms, y=value, colour=Datasets, linetype=Type)) +
  geom_line(aes(x = Symptoms, y = value, col = Datasets, linetype = Type)) +
  geom_point(aes(x = Symptoms, y = value, col = Datasets), 
             shape = 21, fill = "white", size = 1.5, stroke = 1) +
  xlab(" ") + ylab(" ") +
  scale_y_continuous(limits = c(0, 4)) + 
  scale_x_continuous(breaks=c(1:16), labels=shortnames) +
  theme_bw() +
  theme(panel.grid.minor=element_blank(), axis.text.x = element_text(angle = 60, hjust = 1)); p1
dev.off()

# Correlations
cor(means1,sds1, method="spearman") # -.63
cor(means2,sds2, method="spearman") # -.41
cor(means3,sds3, method="spearman") # -.27
cor(means4,sds4, method="spearman") # -.93
cor(means1,means2, method="spearman") # .82 -- highest
cor(means1,means3, method="spearman") # .60
cor(means1,means4, method="spearman") # .72
cor(means2,means3, method="spearman") # .43
cor(means2,means4, method="spearman") # .67
cor(means3,means4, method="spearman") # .34 -- lowest
                                      # ------ mean correlation is 0.60

# Total means across samples
data1sum <- data1miss; data1sum$s <- rowMeans(data1miss) # mean 2.76, sd 0.66
data2sum <- data2miss; data2sum$s <- rowMeans(data2miss) # mean 2.70, sd 0.58
data3sum <- na.omit(data3x); data3sum$s <- rowMeans(na.omit(data3x)) # mean 2.36, sd 0.77
data4sum <- data4miss; data4sum$s <- rowMeans(data4miss) # mean 3.21, sd 0.42

t.test(data1sum$s, data2sum$s) # t = 1.6156, df = 840.15, p-value = 0.107
t.test(data1sum$s, data3sum$s) # t = 10.428, df = 1206.5, p-value < 2.2e-16
t.test(data1sum$s, data4sum$s) # t = -13.706, df = 748.34, p-value < 2.2e-16
t.test(data2sum$s, data3sum$s) # t = 8.5083, df = 882.68, p-value < 2.2e-16
t.test(data2sum$s, data4sum$s) # t = -15.378, df = 518.03, p-value < 2.2e-16
t.test(data3sum$s, data4sum$s) # t = -29.288, df = 1417.3, p-value < 2.2e-16

ttestBF(data1sum$s, data2sum$s) # BF 0.2591402
ttestBF(data1sum$s, data3sum$s) # BF 3.787724e+19
ttestBF(data1sum$s, data4sum$s) # BF 5.865304e+46 
ttestBF(data2sum$s, data3sum$s) # BF 46984319251
ttestBF(data2sum$s, data4sum$s) # BF 6.514741e+58 
ttestBF(data3sum$s, data4sum$s) # BF 3.370608e+151

# Internal consistency; alpha is also a function from ggplot2, so make sure to call this via psych::alpha()
alpha1 <- psych::alpha(cor_auto(data1)); alpha1$total$std.alpha # 0.9319881
alpha2 <- psych::alpha(cor_auto(data2)); alpha2$total$std.alpha # 0.8934923
alpha3 <- psych::alpha(cor_auto(data3)); alpha3$total$std.alpha # 0.9404437
alpha4 <- psych::alpha(cor_auto(data4)); alpha4$total$std.alpha # 0.8524516

# Composite reliability; code from https://www.r-bloggers.com/five-ways-to-calculate-internal-consistency/
testdata1 <- data1
testdata2 <- data2
testdata3 <- data3
testdata4 <- data4

colnames(testdata1)<-print(paste('i',1:16,sep=''))
colnames(testdata2)<-print(paste('i',1:16,sep=''))
colnames(testdata3)<-print(paste('i',1:16,sep=''))
colnames(testdata4)<-print(paste('i',1:16,sep=''))

items <- paste(names(data1), collapse = "+")
model <- paste("bla", items, sep = "=~")

fit1 <- cfa(model, data = testdata1)
fit2 <- cfa(model, data = testdata2)
fit3 <- cfa(model, data = testdata3)
fit4 <- cfa(model, data = testdata4)

l1 <- standardizedSolution(fit1)
l2 <- standardizedSolution(fit2)
l3 <- standardizedSolution(fit3)
l4 <- standardizedSolution(fit4)

l1 <- l1$est.std[l1$op == "=~"]
l2 <- l2$est.std[l2$op == "=~"]
l3 <- l3$est.std[l3$op == "=~"]
l4 <- l4$est.std[l4$op == "=~"]

re1 <- 1 - l1^2
re2 <- 1 - l2^2
re3 <- 1 - l3^2
re4 <- 1 - l4^2

composite_reliability1 <- sum(l1)^2 / (sum(l1)^2 + sum(re1)); composite_reliability1 # 0.9160037
composite_reliability2 <- sum(l2)^2 / (sum(l2)^2 + sum(re2)); composite_reliability2 # 0.8700548
composite_reliability3 <- sum(l3)^2 / (sum(l3)^2 + sum(re3)); composite_reliability3 # 0.9258615
composite_reliability4 <- sum(l4)^2 / (sum(l4)^2 + sum(re4)); composite_reliability4 # 0.8042517

### Save output
# save(means1, means2, means3, means4, sds1, sds2, sds3, sds4, merged, alpha1, alpha2, alpha3, alpha4, 
#      composite_reliability1, composite_reliability2, composite_reliability3, composite_reliability4, file="Means_SDs.RData")


# ---------------------------------------------------------------------------------------
# ---------- 4. Estimate networks individually ------------------------------------------
# ---------------------------------------------------------------------------------------

### Load files
load(file="data_cormatrices.RData")
load(file="networks_individual.RData")
load(file="mgm.Rdata")

### Compute correlations
data1cor <- cor_auto(data1)
data2cor <- cor_auto(data2)
data3cor <- cor_auto(data3)
data4cor <- cor_auto(data4) 

### Individual network estimation
network1 <- estimateNetwork(data1, default="EBICglasso")
network2 <- estimateNetwork(data2, default="EBICglasso")
network3 <- estimateNetwork(data3, default="EBICglasso")
network4 <- estimateNetwork(data4, default="EBICglasso")

L <- averageLayout(network1,network2,network3,network4)

### Before we plot networks, we also want to know the node predictability
# Re-estimate individual networks via mgm 
type=rep('g', 16) 
fit1 <- mgmfit(na.omit(data1), type=type, lev=rep(1,16), d=1) 
pred1 <- predict.mgm(fit1, na.omit(data1), error.continuous='VarExpl')     
fit2 <- mgmfit(na.omit(data2), type=type, lev=rep(1,16), d=1) 
pred2 <- predict.mgm(fit2, na.omit(data1), error.continuous='VarExpl')     
fit3 <- mgmfit(na.omit(data3), type=type, lev=rep(1,16), d=1) 
pred3 <- predict.mgm(fit3, na.omit(data1), error.continuous='VarExpl')     
fit4 <- mgmfit(na.omit(data4), type=type, lev=rep(1,16), d=1) 
pred4 <- predict.mgm(fit4, na.omit(data1), error.continuous='VarExpl')     

# What is the average node predictability in each dataset?
mean(pred1$error$Error) # .43
mean(pred2$error$Error) # .35
mean(pred3$error$Error) # .40
mean(pred4$error$Error) # .37

### Plot networks
pdf("FigS1.pdf", width=10, height=10)
par(mfrow=c(2,2))
network1G <- plot(network1, layout=L, title="Dataset 1", maximum=.47, theme="colorblind", pie=pred1$error$Error,
                  border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE")       # max=0.47
network2G <- plot(network2, layout=L, title="Dataset 2", maximum=.47, theme="colorblind", pie=pred2$error$Error,
                  border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE")       # max=0.46
network3G <- plot(network3, layout=L, title="Dataset 3", maximum=.47, theme="colorblind", pie=pred3$error$Error,
                  border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE")       # max=0.38
network4G <- plot(network4, layout=L, title="Dataset 4", maximum=.47, theme="colorblind", pie=pred4$error$Error,
                  border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE")       # max=0.43
dev.off()

### Save output
# save(data1cor,data2cor,data3cor,data4cor, file="data_cormatrices.RData")
save(network1G, network2G, network3G, network4G, file="networks_individual.RData")
# save(fit1,pred1,fit2,pred2,fit3,pred3,fit4,pred4, file="mgm.Rdata")



# ---------------------------------------------------------------------------------------
# ---------- 5. Stability and accuracy for individually estimated networks --------------
# ---------------------------------------------------------------------------------------

### load files 
load(file="boot1a.Rdata")
load(file="boot1b.Rdata")
load(file="boot2a.Rdata")
load(file="boot2b.Rdata")
load(file="boot3a.Rdata")
load(file="boot3b.Rdata")
load(file="boot4a.Rdata")
load(file="boot4b.Rdata")

### Estimate and save stability and accuracy
boot1a <- bootnet(network1, nBoots = 1000, nCores = 8)
boot1b <- bootnet(network1, nBoots = 1000, type = "case",  nCores = 8)

boot2a <- bootnet(network2, nBoots = 1000, nCores = 8)
boot2b <- bootnet(network2, nBoots = 1000, type = "case",  nCores = 8)

boot3a <- bootnet(network3, nBoots = 1000, nCores = 8)
boot3b <- bootnet(network3, nBoots = 1000, type = "case",  nCores = 8)

boot4a <- bootnet(network4, nBoots = 1000, nCores = 8)
boot4b <- bootnet(network4, nBoots = 1000, type = "case",  nCores = 8)

### Plot edge weight CI
pdf("FigS3.pdf")
plot(boot1a, labels = FALSE, order = "sample") 
plot(boot2a, labels = FALSE, order = "sample") 
plot(boot3a, labels = FALSE, order = "sample") 
plot(boot4a, labels = FALSE, order = "sample") 
dev.off()

### Plot centrality stability
pdf("FigS4.pdf") 
plot(boot1b)
plot(boot2b)
plot(boot3b)
plot(boot4b)
dev.off()

### Centrality stability coefficient
cs1 <- corStability(boot1b)  
cs2 <- corStability(boot2b) 
cs3 <- corStability(boot3b) 
cs4 <- corStability(boot4b) 
cs <- matrix(NA,4,3)
cs[1,1:3] <- round(cs1, digits=2)
cs[2,1:3] <- round(cs2, digits=2)
cs[3,1:3] <- round(cs3, digits=2)
cs[4,1:3] <- round(cs4, digits=2)
colnames(cs) <- c("Betweenness", "Closeness", "Strength")
rownames(cs) <- c("Dataset1", "Dataset2","Dataset3", "Dataset4")
sink("TableS1.txt")
cs
sink()

### Edge weights diff test
pdf("FigS5.pdf")
plot(boot1a, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
plot(boot2a, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
plot(boot3a, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
plot(boot4a, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()

### Centrality diff test
pdf("FigS6.pdf")
plot(boot1a, "strength", order="sample", labels=FALSE) 
plot(boot2a, "strength", order="sample", labels=FALSE) 
plot(boot3a, "strength", order="sample", labels=FALSE) 
plot(boot4a, "strength", order="sample", labels=FALSE) 
dev.off()

### Conclusion: 
# all networks have CS coefficients for node strength > 0.5; looks good!

### Save output
# save(boot1a, file = "boot1a.Rdata")
# save(boot1b, file = "boot1b.Rdata")
# save(boot2a, file = "boot2a.Rdata")
# save(boot2b, file = "boot2b.Rdata")
# save(boot3a, file = "boot3a.Rdata")
# save(boot3b, file = "boot3b.Rdata")
# save(boot4a, file = "boot4a.Rdata")
# save(boot4b, file = "boot4b.Rdata")



# ---------------------------------------------------------------------------------------
# ---------- 6. Joint network estimation ------------------------------------------------
# ---------------------------------------------------------------------------------------

### Load files
load(file="JointEstimation.RData")

### Joint estimation using crossvalidation; this is the main analysis of the paper
EGN1 <- EstimateGroupNetwork(list(data1, data2, data3, data4), method="crossvalidation", 
        strategy="sequential", simplifyOutput = FALSE, seed=1337, ncores=8, covfun = cor_auto)

pdf("Fig1.pdf", width=10, height=10) # maximum values for the 4 networks: .42, .45, .37, .44
par(mfrow=c(2,2))
g1 <- qgraph(EGN1$network[[1]], layout = L, title = "Dataset 1", maximum=.45, theme="colorblind", pie=pred1$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g2 <- qgraph(EGN1$network[[2]], layout = L, title = "Dataset 2", maximum=.45, theme="colorblind", pie=pred2$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g3 <- qgraph(EGN1$network[[3]], layout = L, title = "Dataset 3", maximum=.45, theme="colorblind", pie=pred3$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g4 <- qgraph(EGN1$network[[4]], layout = L, title = "Dataset 4", maximum=.45, theme="colorblind", pie=pred4$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
dev.off()   

pdf("Fig1_bw.pdf", width=10, height=10) # maximum values for the 4 networks: .42, .45, .37, .44
par(mfrow=c(2,2))
g1 <- qgraph(EGN1$network[[1]], layout = L, title = "Dataset 1", maximum=.45, theme="gray", pie=pred1$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g2 <- qgraph(EGN1$network[[2]], layout = L, title = "Dataset 2", maximum=.45, theme="gray", pie=pred2$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g3 <- qgraph(EGN1$network[[3]], layout = L, title = "Dataset 3", maximum=.45, theme="gray", pie=pred3$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g4 <- qgraph(EGN1$network[[4]], layout = L, title = "Dataset 4", maximum=.45, theme="gray", pie=pred4$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
dev.off()   

### Joint estimation using default method InformationCriterion; reported in supplementary materials
EGN2 <- EstimateGroupNetwork(list(data1, data2, data3, data4), method="InformationCriterion", 
        strategy = "sequential", simplifyOutput = FALSE, seed=1337, ncores=8, covfun = cor_auto)

pdf("FigS2.pdf", width=10, height=10) # maximum values for the 4 networks: .47, .46, .37, .44
par(mfrow=c(2,2))
g1b <- qgraph(EGN2$network[[1]], layout = L, title = "Dataset 1", maximum=.47, theme="colorblind", pie=pred1$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g2b <- qgraph(EGN2$network[[2]], layout = L, title = "Dataset 2", maximum=.47, theme="colorblind", pie=pred2$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g3b <- qgraph(EGN2$network[[3]], layout = L, title = "Dataset 3", maximum=.47, theme="colorblind", pie=pred3$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
g4b <- qgraph(EGN2$network[[4]], layout = L, title = "Dataset 4", maximum=.47, theme="colorblind", pie=pred4$error$Error,
             border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE") 
dev.off()

### We use cross-validation estimation from here on.

### Correlations
# Correlations joint networks with individual networks
cor(getWmat(g2)[lower.tri(getWmat(g2))], getWmat(network2)[lower.tri(getWmat(network2))], method="spearman")   #0.96
cor(getWmat(g3)[lower.tri(getWmat(g3))], getWmat(network3)[lower.tri(getWmat(network3))], method="spearman")   #0.95
cor(getWmat(g4)[lower.tri(getWmat(g4))], getWmat(network4)[lower.tri(getWmat(network4))], method="spearman")   #0.95

# Correlations joint networks with each other
cor(getWmat(g1)[lower.tri(getWmat(g1))], getWmat(g2)[lower.tri(getWmat(g2))],	method="spearman") #0.73
cor(getWmat(g1)[lower.tri(getWmat(g1))], getWmat(g3)[lower.tri(getWmat(g3))], method="spearman") #0.74
cor(getWmat(g1)[lower.tri(getWmat(g1))], getWmat(g4)[lower.tri(getWmat(g4))], method="spearman") #0.67
cor(getWmat(g2)[lower.tri(getWmat(g2))], getWmat(g3)[lower.tri(getWmat(g3))], method="spearman") #0.73
cor(getWmat(g2)[lower.tri(getWmat(g2))], getWmat(g4)[lower.tri(getWmat(g4))], method="spearman") #0.62
cor(getWmat(g3)[lower.tri(getWmat(g3))], getWmat(g4)[lower.tri(getWmat(g4))], method="spearman") #0.69
mean(.73,.74,.67,.73,.62,.69) #.73

### Save output
save(L, g1,g2,g3,g4,g1b,g2b,g3b,g4b, file="JointEstimation.RData")



# ---------------------------------------------------------------------------------------
# ---------- 7. Centrality for 4 jointly estimated networks -----------------------------
# ---------------------------------------------------------------------------------------

### Load objects
load(file="centrality.RData")

### Estimate and plot centrality
cents <- as.data.frame(cbind(scale(centrality(g1)$InDegree),
                             scale(centrality(g2)$InDegree),
                             scale(centrality(g3)$InDegree),
                             scale(centrality(g4)$InDegree)))

cents <- mutate(cents, id = rownames(cents))
colnames(cents)<-c("1", "2", "3", "4", "Symptoms")
cents_long <- melt(cents, id="Symptoms")
cents_long$Symptoms <- as.numeric(cents_long$Symptoms)
names(cents_long)[2] <- "Datasets"

pdf("Fig2.pdf", width=6, height=4, useDingbats=FALSE)
p3 <- ggplot(data=cents_long, aes(x=Symptoms, y=value, colour=Datasets)) +
  geom_line() +
  geom_point(shape = 21, fill = "white", size = 1.5, stroke = 1) +
  xlab(" ") + ylab("Centrality") +
  scale_y_continuous(limits = c(-3, 3)) + 
  scale_x_continuous(breaks=c(1:16), labels=shortnames) +
  theme_bw() +
  theme(panel.grid.minor=element_blank(), axis.text.x = element_text(angle = 60, hjust = 1)); p3
  # coord_flip()
dev.off()

### Correlations
# How closely is centrality order related across networks
cor(scale(centrality(g1)$InDegree), scale(centrality(g2)$InDegree)) # correlations between 0.63 and 0.75
cor(scale(centrality(g1)$InDegree), scale(centrality(g3)$InDegree)) # we can use Pearson correlation here because after scaling because the histograms look quite normal
cor(scale(centrality(g1)$InDegree), scale(centrality(g4)$InDegree))
cor(scale(centrality(g2)$InDegree), scale(centrality(g3)$InDegree))
cor(scale(centrality(g2)$InDegree), scale(centrality(g4)$InDegree))
cor(scale(centrality(g3)$InDegree), scale(centrality(g4)$InDegree))
    
# Correlation centrality individual networks & symptom means
cor(scale(centrality(g1)$InDegree), means1, method="spearman") # 0.33
cor(scale(centrality(g2)$InDegree), means2, method="spearman") # 0.39
cor(scale(centrality(g3)$InDegree), means3, method="spearman") # 0.10
cor(scale(centrality(g4)$InDegree), means4, method="spearman") # 0.58

# How closely is predictability related to degree centrality? 
cor(pred1$error$Error, centrality(g1)$InDegree) # .92
cor(pred2$error$Error, centrality(g2)$InDegree) # .80
cor(pred3$error$Error, centrality(g3)$InDegree) # .62
cor(pred4$error$Error, centrality(g4)$InDegree) # .74

### Betweenness and Closeness for Supplementary
pdf("FigS8.pdf")
centralityPlot(g1)
centralityPlot(g2)
centralityPlot(g3)
centralityPlot(g4)
dev.off()

### Save files
# save(p3, cents, file="centrality.RData")



# ---------------------------------------------------------------------------------------
# ---------- 8. Network comparison tests for 4 jointly estimated networks ---------------
# ---------------------------------------------------------------------------------------

### Load files
load(file="NCT.RData")

### First, how similar are polychoric and Pearson?
c1 <- cor(data1miss)
c1b <- cor_auto(data1miss)
cor(c1[lower.tri(c1)], 	c1b[lower.tri(c1b)], 	method="spearman") #0.996
c2 <- cor(data2miss)
c2b <- cor_auto(data2miss)
cor(c2[lower.tri(c2)], 	c2b[lower.tri(c2b)], 	method="spearman") #0.994
c3 <- cor(data3miss)
c3b <- cor_auto(data3miss)
cor(c3[lower.tri(c3)], 	c3b[lower.tri(c3b)], 	method="spearman") #0.985
c4 <- cor(data4miss)
c4b <- cor_auto(data4miss)
cor(c4[lower.tri(c4)], 	c4b[lower.tri(c4b)], 	method="spearman") #0.99

# since they are very similar, we can probably use the NCT() that is only validated for Pearson, not poylchoric correlations

### NCT topology
set.seed(1337)
compare_12 <- NCT(data1miss,data2miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
compare_13 <- NCT(data1miss,data3miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
compare_14 <- NCT(data1miss,data4miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
compare_23 <- NCT(data2miss,data3miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
compare_24 <- NCT(data2miss,data4miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
compare_34 <- NCT(data3miss,data4miss, it=5000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)

comparison_topology <- matrix(NA,4,4)
comparison_topology[1,2] <- compare_12$nwinv.pval
comparison_topology[1,3] <- compare_13$nwinv.pval
comparison_topology[1,4] <- compare_14$nwinv.pval
comparison_topology[2,3] <- compare_23$nwinv.pval
comparison_topology[2,4] <- compare_24$nwinv.pval
comparison_topology[3,4] <- compare_34$nwinv.pval; comparison_topology 
#      [,1]   [,2]    [,3]   [,4]   
# [1,]   NA  0.0012 0.0018  0.0082    # all p-values significant with alpha=0.05
# [2,]   NA     NA  0.0054  0.0000
# [3,]   NA     NA     NA   0.0000
# [4,]   NA     NA     NA     NA

### quantification of differences: count significantly different edges (total number 120)
sum(compare_12$einv.pvals$"p-value" < 0.05) # 2; 1.7% of 120 edges
sum(compare_13$einv.pvals$"p-value" < 0.05) # 3; 2.5%
sum(compare_14$einv.pvals$"p-value" < 0.05) # 2; 1.7%
sum(compare_23$einv.pvals$"p-value" < 0.05) # 3; 2.5%
sum(compare_24$einv.pvals$"p-value" < 0.05) # 4; 3.3%
sum(compare_34$einv.pvals$"p-value" < 0.05) # 8; 6.7%
mean(c(1.7,1.7,2.5, 2.5, 3.3, 6.7)) # 3.07

# sink("TableS2.txt")
# compare_12$einv.pvals
# compare_13$einv.pvals
# compare_14$einv.pvals
# compare_23$einv.pvals
# compare_24$einv.pvals
# compare_34$einv.pvals
# sink()

### NCT global strength
comparison_strength <- matrix(NA,4,4)
comparison_strength[1,2] <- compare_12$glstrinv.pval 
comparison_strength[1,3] <- compare_13$glstrinv.pval 
comparison_strength[1,4] <- compare_14$glstrinv.pval 
comparison_strength[2,3] <- compare_23$glstrinv.pval 
comparison_strength[2,4] <- compare_24$glstrinv.pval
comparison_strength[3,4] <- compare_34$glstrinv.pval; comparison_strength
# global strength network1: 7.052783 
# global strength network2: 6.593411
# global strength network3: 7.367283
# global strength network4: 6.017061
#       [,1]  [,2]   [,3]    [,4]
# [1,]   NA  0.007  0.1518  0.000   # significant: 1-2, 1-4, 2-3, 3-4 
# [2,]   NA    NA   0.0002  0.039   
# [3,]   NA    NA     NA    0.000
# [4,]   NA    NA     NA      NA

# save(compare_12, compare_13, compare_14, compare_23, compare_24, compare_34, comparison_strength, comparison_topology, file="NCT.RData")

### NCT topology take 2; to avoid low power due to different sample sizes, we sample 5 times equal samples and run the NCT 5 times each for each comparison
# nrow(data1miss) #517
# nrow(data2miss) #363
# nrow(data3miss) #923
# nrow(data4miss) #928
# 
# set.seed(1); compare_12X1 <- NCT(sample_n(data1miss, 363),data2miss, it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_12X2 <- NCT(sample_n(data1miss, 363),data2miss, it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_12X3 <- NCT(sample_n(data1miss, 363),data2miss, it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_12X4 <- NCT(sample_n(data1miss, 363),data2miss, it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_12X5 <- NCT(sample_n(data1miss, 363),data2miss, it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# 
# set.seed(1); compare_13X1 <- NCT(data1miss,sample_n(data3miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_13X2 <- NCT(data1miss,sample_n(data3miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_13X3 <- NCT(data1miss,sample_n(data3miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_13X4 <- NCT(data1miss,sample_n(data3miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_13X5 <- NCT(data1miss,sample_n(data3miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# 
# set.seed(1); compare_14X1 <- NCT(data1miss,sample_n(data4miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_14X2 <- NCT(data1miss,sample_n(data4miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_14X3 <- NCT(data1miss,sample_n(data4miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_14X4 <- NCT(data1miss,sample_n(data4miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_14X5 <- NCT(data1miss,sample_n(data4miss, 517), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
#                    
# set.seed(1); compare_23X1 <- NCT(data2miss,sample_n(data3miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_23X2 <- NCT(data2miss,sample_n(data3miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_23X3 <- NCT(data2miss,sample_n(data3miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_23X4 <- NCT(data2miss,sample_n(data3miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_23X5 <- NCT(data2miss,sample_n(data3miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# 
# set.seed(1); compare_24X1 <- NCT(data2miss,sample_n(data4miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_24X2 <- NCT(data2miss,sample_n(data4miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_24X3 <- NCT(data2miss,sample_n(data4miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_24X4 <- NCT(data2miss,sample_n(data4miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_24X5 <- NCT(data2miss,sample_n(data4miss, 363), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# 
# set.seed(1); compare_34X1 <- NCT(data3miss,sample_n(data4miss, 923), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(2); compare_34X2 <- NCT(data3miss,sample_n(data4miss, 923), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(3); compare_34X3 <- NCT(data3miss,sample_n(data4miss, 923), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(4); compare_34X4 <- NCT(data3miss,sample_n(data4miss, 923), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# set.seed(5); compare_34X5 <- NCT(data3miss,sample_n(data4miss, 923), it=1000, binary.data=FALSE, test.edges=TRUE, edges='all', progressbar=TRUE)
# 
# # structural invariance
# compare_12X1$nwinv.pval # 0.006
# compare_12X2$nwinv.pval # 0.000
# compare_12X3$nwinv.pval # 0.012
# compare_12X4$nwinv.pval # 0.013
# compare_12X5$nwinv.pval # 0.002
# 
# compare_13X1$nwinv.pval # 0.033
# compare_13X2$nwinv.pval # 0.063
# compare_13X3$nwinv.pval # 0.001
# compare_13X4$nwinv.pval # 0.011
# compare_13X5$nwinv.pval # 0.002
# 
# compare_14X1$nwinv.pval # 0.023
# compare_14X2$nwinv.pval # 0.004
# compare_14X3$nwinv.pval # 0.003
# compare_14X4$nwinv.pval # 0.006
# compare_14X5$nwinv.pval # 0.012
# 
# compare_23X1$nwinv.pval # 0.009
# compare_23X2$nwinv.pval # 0.005
# compare_23X3$nwinv.pval # 0.028
# compare_23X4$nwinv.pval # 0.003
# compare_23X5$nwinv.pval # 0.059
# 
# compare_24X1$nwinv.pval # 0.001
# compare_24X2$nwinv.pval # 0.000
# compare_24X3$nwinv.pval # 0.000
# compare_24X4$nwinv.pval # 0.000
# compare_24X5$nwinv.pval # 0.001
# 
# compare_34X1$nwinv.pval # 0.000
# compare_34X2$nwinv.pval # 0.000
# compare_34X3$nwinv.pval # 0.000
# compare_34X4$nwinv.pval # 0.000
# compare_34X5$nwinv.pval # 0.000
# 
# # individual edge weights
# sum(compare_12X1$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_12X2$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_12X3$einv.pvals$"p-value" < 0.0083) # 2
# sum(compare_12X4$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_12X5$einv.pvals$"p-value" < 0.0083) # 3; mean=2
# 
# sum(compare_13X1$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_13X2$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_13X3$einv.pvals$"p-value" < 0.0083) # 5
# sum(compare_13X4$einv.pvals$"p-value" < 0.0083) # 4
# sum(compare_13X5$einv.pvals$"p-value" < 0.0083) # 2; mean=3.4
# 
# sum(compare_14X1$einv.pvals$"p-value" < 0.0083) # 2
# sum(compare_14X2$einv.pvals$"p-value" < 0.0083) # 2
# sum(compare_14X3$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_14X4$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_14X5$einv.pvals$"p-value" < 0.0083) # 0; mean=1.2
# 
# sum(compare_23X1$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_23X2$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_23X3$einv.pvals$"p-value" < 0.0083) # 2
# sum(compare_23X4$einv.pvals$"p-value" < 0.0083) # 4
# sum(compare_23X5$einv.pvals$"p-value" < 0.0083) # 0; mean=2
# 
# sum(compare_24X1$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_24X2$einv.pvals$"p-value" < 0.0083) # 2
# sum(compare_24X3$einv.pvals$"p-value" < 0.0083) # 3
# sum(compare_24X4$einv.pvals$"p-value" < 0.0083) # 1
# sum(compare_24X5$einv.pvals$"p-value" < 0.0083) # 4; mean=2.6
# 
# sum(compare_34X1$einv.pvals$"p-value" < 0.0083) # 11
# sum(compare_34X2$einv.pvals$"p-value" < 0.0083) # 6
# sum(compare_34X3$einv.pvals$"p-value" < 0.0083) # 9
# sum(compare_34X4$einv.pvals$"p-value" < 0.0083) # 5
# sum(compare_34X5$einv.pvals$"p-value" < 0.0083) # 9; mean=8



# ---------------------------------------------------------------------------------------
# ---------- 9. Pool data into one full network -----------------------------------------
# ---------------------------------------------------------------------------------------

### Load files
load("network_pooled.RData")

### Full dataset
data_full <- rbind(data1,data2,data3,data4)
nrow(data_full)  # 2782

### Method 1: estimate full network (note: this weighs by sample size)
data_full_cor<-cor_auto(data_full)
network_full <- estimateNetwork(data_full, default="EBICglasso")
g_full <- plot(network_full, layout=L, border.width=2, vsize=8, border.color='#555555', label.color="#555555", color="#EEEEEE",
               labels=TRUE, nodeNames=names, legend.cex = 0.5, theme="colorblind")
cent_full <- scale(centrality(g_full)$InDegree)

### Method 2: average coefficients (note: this weighs all samples equally); 
### We decided to use this estimation for the paper because we don't want to weigh the importance of the four datasets by sampe size
g_full2 <- (getWmat(g1b) + getWmat(g2b) + getWmat(g3b) + getWmat(g4b)) / 4
cent_full2 <- scale(centrality(g_full2)$InDegree)
cent_full2C <- scale(centrality(g_full2)$Closeness)
cent_full2B <- scale(centrality(g_full2)$Betweenness)
pdf("Fig3a.pdf")
graph_full2 <- qgraph(g_full2, layout=L, border.width=2, vsize=8, border.color='#555555', label.color="#555555", color="#EEEEEE",
                legend.cex = 0.6, theme="colorblind")
dev.off()

pdf("Fig3a_bw.pdf")
graph_full2 <- qgraph(g_full2, layout=L, border.width=2, vsize=8, border.color='#555555', label.color="#555555", color="#EEEEEE",
                      legend.cex = 0.6, theme="gray")
dev.off()

### Similarity
cor(getWmat(g_full)[lower.tri(getWmat(g_full))], 	getWmat(g_full2)[lower.tri(getWmat(g_full2))], 	method="spearman") #0.86
cor(cent_full, cent_full2, method="spearman") #0.72

### Plot centrality
cents2 <- as.data.frame(cent_full2)
cents2 <- mutate(cents2, id = rownames(cents2))
colnames(cents2)<-c("value", "Symptoms")
cents2$Symptoms <- as.numeric(cents2$Symptoms)

pdf("Fig3c.pdf", width=6, height=3)
p4 <- ggplot(data=cents2, aes(x=Symptoms, y=value)) +
  geom_line(color="#555555") +
  geom_point(shape = 21, fill = "white", size = 2, stroke = 1, color="#555555") +
  xlab(" ") + ylab("Centrality") +
  scale_y_continuous(limits = c(-3, 3)) + 
  scale_x_continuous(breaks=c(1:16), labels=shortnames) +
  theme_bw() +
  theme(panel.grid.minor=element_blank(), axis.text.x = element_text(angle = 60, hjust = 1)); p4
  # coord_flip();
dev.off()

# Construct a network where edges are standard deviations across edge weights of networks
edgeMeanJoint <- matrix(0,16,16)
edgeSDJoint <- matrix(0,16,16)
for(i in 1:16){
  for(j in 1:16) {
    vector  <-  c(getWmat(g1b)[i,j],getWmat(g2b)[i,j],getWmat(g3b)[i,j],getWmat(g4b)[i,j])
    edgeMeanJoint[i,j] <- mean(vector) 
    edgeSDJoint[i,j] <- sd(vector) 
  } 
} 
min(edgeSDJoint) # 0 
max(edgeSDJoint) # .15

pdf("Fig3b.pdf")
var_joint <- qgraph(edgeSDJoint, layout=L, theme="colorblind", border.width=2, vsize=8, 
                    border.color='#555555', label.color="#555555", color="#ffffff", edge.color="#666666", maximum=.18, minimum=.03) 
dev.off()

### Save objects
save(data_full_cor, g_full, cent_full, g_full2, cent_full2, graph_full2, cents2, var_joint, file="network_pooled.RData")



# ---------------------------------------------------------------------------------------
# ---------- 10. Compare to McNally et al. 2015 -----------------------------------------
# ---------------------------------------------------------------------------------------

MCdata <- read_csv("~/Dropbox/Research/DB Shared Folders/2017 - PTSD 4 clinical samples/analysis/Mcnally2014.RDS.csv")
MCdata <- MCdata[,-1]
MCdata[,18] <- rep(0,nrow(MCdata))

# combine psycholigal and physiological reactivity in the same way we did for our data to obtain 16 symptoms
for (i in 1:nrow(MCdata)) {
  MCdata[[i,18]] <- pmax(MCdata[[i,1]], MCdata[[i,5]])
};

# re-order to fit out symptom order
MCdata2 <- MCdata[,c(1:3, 6:18)]
MCdata2 <- MCdata2[,c(1,3,2,8,9,15,13,11,14,12,5,6,7,10,4,16)]
MCdata2 <- MCdata2[,c(1,3,2,16,15,11,12,13,4,5,14,8,10,7,9,6)]
colnames(MCdata2) <- c(1:16)

# compare mean symptom level to our data
means5 <- colMeans(MCdata2, na.rm=T)
means5 <- means5 * 4/5; 
means5x <- mean(means5); means5x # 1.71
means_average <- mean(c(means1,means2,means3,means4)); means_average # 2.76

# estimate network
MCnetwork <- estimateNetwork(MCdata2, default="EBICglasso")

# plot
pdf("FigS7.pdf", width=10, height=6)
layout(t(1:2))
MCplot <- plot(MCnetwork, layout=L,  theme="colorblind", title="McNally et al. 2015",
               border.width=2, vsize=9, border.color='#555555', label.color="#555555", 
               color="#EEEEEE")

fried17 <- qgraph(g_full2 , layout=L, theme="colorblind", title="Present paper, Fried et al. 2017", 
               border.width=2, vsize=9, border.color='#555555', label.color="#555555", maximum=.66,
               color="#EEEEEE")
dev.off()

#compare connectivity 
sum(abs(MCnetwork$graph))/2 # 7.47
sum(abs(g_full2))/2 # 7.15

cor(MCnetwork$graph[lower.tri(MCnetwork$graph)], g_full2[lower.tri(g_full2)], method="spearman")   #0.51
cor(scale(centrality(MCnetwork)$InDegree), cent_full2) # 0.55



# ---------------------------------------------------------------------------------------
# ---------- 11.  How to reproduce network analysis without data ------------------------
# ---------------------------------------------------------------------------------------

# Networks were estimated based on the raw clinical data which we cannot share
# All code above is reproducible in the sense that you have the model output and use the R output to obtain identical results

load(file="networks_individual.RData") # for instance will give you the individual networks 
                                       # which you can plot using the code provided above

# But if you want to re-estimate the networks from scratch, using correlations as input, you can do so, too
# For this you have to use the EBICglasso function from the qgraph package, and specify the sample size for each dataset

load(file="data_cormatrices.RData")

ReestimatedNetwork1 <- EBICglasso(data1cor, n=526) # see paper for sample sizes
qgraph(ReestimatedNetwork1)

# Now we add the same graphical arguments to qgraph() we used above, resulting in networks identical to the paper
# Note that this is the top left plot of the Supplementary Figure S1 (because we use the jointly estimated networks in the paper, not the individal networks we use here)
# It's important you run all code above first, and load all RData files, to obtain all objects needed for plotting (e.g. pred1$error$Error)

GraphReestimated1 <- qgraph(ReestimatedNetwork1, layout=L, title="Dataset 1", maximum=.47, theme="colorblind", pie=pred1$error$Error,
                            border.width=2, vsize=10, border.color='#555555', label.color="#555555", color="#EEEEEE")

# This gives us the identical network as Supplementary Figure 1. Et voila!